# saga

saga is a set of tools for version control. As a user, you can use saga to manage any project... TODO.

As a developer, you can use saga's framework to add intelligent version control to any software project. Simply tell saga what your file looks like, and saga will auto-magically allow git-level branching, patching, and merging. Oh gee, think of the collaboration possible!

## Instructions

### Requirments

Make sure git, python3, pip and virtualenv are installed on your computer. 

### Setup

To download and setup the software on macOS and Linux:

~~~~
git clone https://github.com/naterush/version-control.git;
cd version-control;
python3 -m venv env;
source env/bin/activate;
pip install -r requirements.txt;
~~~~

### Using saga

Coming soon!

### Running Tests

When inside of the python virtual enviorment:
~~~~
python -m pytest
~~~~
